function [value] = GPIB_convert(input, entry_number, format)
%********************************************************************************
%* COPYRIGHT:      (c) 2000 Rohde & Schwarz, Munich
%* MODULE:         GPIB_convert.m
%* ABBREVIATION:   conversion of strings from IEC bus results to numbers
%* COMPILER:       --- (Matlab-Interpreter)
%* LANGUAGE:       Matlab
%* AUTHOR:         R. Lorenzen
%* ABSTRACT:       Converts the desired input string into a number
%* PARAMETERS:		 input:				input string
%*					 entry_number:		number of string to be converted (, as seperator)
%*                   format:            format of element, 'FLOAT', 'HEX24'
%* PREMISES:       non
%* REMARKS:        none
%* HISTORY:        07.09.00 Erstellung
%*                 20.03.03 Von 'convert' auf 'GPIB_convert' umbenannt, da es schon
%*                          eine matlab function 'convert' gibt
%* REVIEW:         keine
%**********************************************************************************/

if nargin < 3
    format='FLOAT';
end;

kommas=findstr(',',input);					%finde Indizes der Kommas			
nof_entries=length(kommas)+1;				%Anzahl der Elemente

start=[1 kommas+1];							%Start der Elemente
ende=[kommas-1 length(input)];			    %Ende der Elemente
len=(ende-start+1);							%Lnge der Elemente

entry=[];
for i=1:nof_entries
   entry(i,1:len(i))=((input(start(i):ende(i))));
end;   

for i=1:length(entry_number)
	temp=char(entry(entry_number(i),:));	%Zugriff auf gewnschtes Element
    if format=='FLOAT'
        temp=str2num(temp);					%Konvertierung in Zahl
	    if isempty(temp)					%Wenn der String keine Zahl war,
   	        temp=NaN;						%dann wird NaN ausgegeben
	    end;								%Dies kann in matlab weiter gehandled werden
        value(i)=temp;
    end;

    if format=='HEX24'
        temp=strtok(temp);                  %ignore blanks
        temp=hex2dec(temp(3:length(temp)));	%Konvertierung in Zahl (ignoriere #H)
	    if isempty(temp)					%Wenn der String keine Zahl war,
   	        temp=NaN;						%dann wird NaN ausgegeben
        else								%Dies kann in matlab weiter gehandled werden
            if temp>(2^23-1)
                temp=temp-2^24;
            end;%if
        end;
        value(i)=temp/2^23;
    end;%if
end;%for